@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,11 +12,9 @@
 #
 ##############################################################################
 """Traversal Namespace Tests
-
-$Id: test_namespacetrversal.py 100317 2009-05-23 22:05:12Z shane $
 """
 from unittest import main
-from zope.testing.doctestunit import DocTestSuite
+from doctest import DocTestSuite
 from zope.component.testing import setUp, tearDown
 
 def test_suite():
